@@ -55,7 +55,7 @@ use constant NEXT    => 4;   # link to next item in cache linked list
 use constant STAT    => 5;   # Time last stat()ed
 use constant MSWin32 => $^O eq 'MSWin32';
 
-our $VERSION = '3.007';
+our $VERSION = '3.008';
 our $DEBUG   = 0 unless defined $DEBUG;
 our $ERROR   = '';
 
@@ -578,6 +578,10 @@ sub _load_compiled {
     # with Module::Name -> Module/Name.pm translation.
     my $fpath = File::Spec->rel2abs( $file );
 
+    return $self->error("compiled template missing path") unless defined $fpath;
+
+    ($fpath) = $fpath =~ /^(.*)$/s;
+
     my $compiled;
 
     # load compiled template via require();  we zap any
